@@ -17,32 +17,31 @@
 #ifndef PNG_WRITER_H
 #define PNG_WRITER_H
 
+#include <png.h>
 #include <string>
 #include <vector>
-#include <png.h>
 
 #include "imagewriter.h"
 
-namespace ffmpegthumbnailer
-{
+namespace ffmpegthumbnailer {
 
 class PngWriter : public ImageWriter
 {
 public:
     PngWriter(const std::string& outputFile);
     PngWriter(std::vector<uint8_t>& outputBuffer);
-    ~PngWriter();
+    ~PngWriter() override;
 
-    void setText(const std::string& key, const std::string& value);
-    void writeFrame(uint8_t** rgbData, int width, int height, int quality);
+    void setText(const std::string& key, const std::string& value) override;
+    void writeFrame(uint8_t** rgbData, int width, int height, int quality) override;
 
 private:
     void init();
 
 private:
-    FILE*                   m_FilePtr;
-    png_structp             m_PngPtr;
-    png_infop               m_InfoPtr;
+    FILE* m_FilePtr;
+    png_structp m_PngPtr;
+    png_infop m_InfoPtr;
 };
 
 }
